#
# spec file for package perl-XML-LibXML
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-XML-LibXML
Version:        2.0019
Release:        8.14
%define cpan_name XML-LibXML
Summary:        Perl Binding for libxml2
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/XML-LibXML/
Source:         http://www.cpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Patch0:         CVE-2015-3451.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.56
BuildRequires:  perl(XML::NamespaceSupport) >= 1.07
BuildRequires:  perl(XML::SAX) >= 0.11
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.0
Requires:       perl(XML::NamespaceSupport) >= 1.07
Requires:       perl(XML::SAX) >= 0.11
Provides:       perl-XML-LibXML-Common = %{version}
Obsoletes:      perl-XML-LibXML-Common < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}

%description
This module implements a Perl interface to the Gnome libxml2 library which
provides interfaces for parsing and manipulating XML files. This module allows
Perl programmers to make use of the highly capable validating XML parser and
the high performance DOM implementation.

%prep
%setup -q -n %{cpan_name}-%{version}
%patch0 -p1

%build
# [2,7,1,0], # broken release, broken utf-16
%if 0%{?suse_version} == 1110
perl Makefile.PL OPTIMIZE="%{optflags} -Wall" FORCE=1
%else
perl Makefile.PL OPTIMIZE="%{optflags} -Wall"
%endif
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
rm -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root)
%doc Changes LICENSE README

%changelog
* Thu May 28 2015 jkeil@suse.de
- Fix bnc#929237: CVE-2015-3451
  * CVE-2015-3451.patch
  * "expand_entities" option was not preserved under some circumstances
* Sat Jul 27 2013 coolo@suse.com
- updated to 2.0019
  - Correct typos reported in RT #86599.
  - https://rt.cpan.org/Ticket/Display.html?id=86599
  - Thanks to dsteinbrunner.
  - Revert previous change of minimal version of libxml2.
  - This change proved to be unpopular and didn't prevent
    the CPAN test failures.
  - By SHLOMIF
  - Made the minimal version of libxml2 2.9.0 as previous versions were
    too buggy due to spuriourous CPAN test failures.
  - Please upgrade.
  - By SHLOMIF
  - Don't enable XML_PARSE_HUGE by default.
  - Fix the previous version due to a mercurial SNAFU.
  - Don't enable XML_PARSE_HUGE by default.
  - https://bitbucket.org/shlomif/perl-xml-libxml/pull-request/19
  - Thanks to Grant McLean ( https://metacpan.org/author/GRANTM ) for
    the bug report and patch.
  - Got 40reader_mem_error.t to not fetch the external DTDs.
  - https://rt.cpan.org/Public/Bug/Display.html?id=81703
  - Thanks to Alexandr Ciornii (CHORNY) for the report and Slaven
    Rezic (SREZIC) for the analysis and a proposed fix.
  - Fix a memory error (double-free) in XML::LibXML::Reader if we reached
    EOF and
    then called destroy.
  - discovered by Shlomi Fish.
  - Fixed by Shlomi Fish.
  - see t/40reader_mem_error.t
- remove upstreamed perl-XML-LibXML-bigendian.patch
* Fri May 25 2012 dvaleev@suse.com
- STRLEN has 64 bits here and int has 32, so the (int*) cast in
  XML::LibXML::Document::toStringHTML() makes htmlDocDumpMemory() store
  the 32-bit length of the result into a 64-bit variable.  Depending on
  the endianness, it either works OK (LE) or corrupts the variable (BE)
  Just use an 'int' instead, and cast it to an STRLEN later in the
  newSVpvn() call.
* Mon Apr 16 2012 dvaleev@suse.com
- disable 12html.t as it causes OOM on ppc64
* Wed Feb 29 2012 vcizek@suse.com
- update to 1.95
  - Got rid of a broken test (at least with recent libxml2s) in
    t/03doc.t :
  - https://rt.cpan.org/Ticket/Display.html?id=75403
  - The problem was that the test tested for an undefined XML
    namespace, a behaviour which was changed in a recent libxml2
    release.
  1.94
  - Fix XML::LibXML::Element tests for ineqaulity with == and eq.
  - Fixes https://rt.cpan.org/Ticket/Display.html?id=75505 .
  - Thanks to Mark Overmeer for the report and for a preliminary patch
    to t/71overload.t .
    1.93            Mon Feb 27 11:15:50 IST 2012
  - Fix XML::LibXML::Element comparision with == and eq.
  - Fixes https://rt.cpan.org/Ticket/Display.html?id=75257 ,
    https://rt.cpan.org/Ticket/Display.html?id=75293 ,
    https://rt.cpan.org/Ticket/Display.html?id=75259 .
  - Thanks to Toby Inkster for a preliminary patch (that was modified by
    me) and to the various people who reported the problem.
* Wed Feb 22 2012 vcizek@suse.com
- update to 1.92
  - Fix for test failure on perls < 5.10.
  - Fixes https://rt.cpan.org/Public/Bug/Display.html?id=75195
  - Thanks to Paul for the report, and for a patch that was not
    accepted.
  1.91            Tue Feb 21 13:57:54 IST 2012
  - Overload hash dereferencing on XML::LibXML::Elements, to provide
    access to the element's attributes.
  - See XML::LibXML::AttributeHash for details.
  - Thanks to Toby Inkster.
  - Pull some commits from Toby Inkster to add more convenient methods
    to XML::LibXML::NodeList such as sort, map, grep, etc.
  - https://bitbucket.org/shlomif/perl-xml-libxml/pull-request/11/xml-libxml-nodelist-improvements
  - Thanks, Toby!
  - Printed some warnings regardless if DEBUG is on.
  - Thanks to http://search.cpan.org/~mstrout/ for the suggestion.
* Mon Jan  9 2012 vcizek@suse.com
- update to 1.90
  - Pull a commit from Aaron Crange to fix compilation bugs in Devel.xs:
  - local variable declarations must be in the PREINIT section,
    not `CODE`, at least for some compiler/OS combinations.
  - Thanks, Aaron!
* Mon Jan  2 2012 vcizek@suse.cz
- update to 1.89
  - Apply a patch with spelling fixes by Kevin Lyda :
  - https://rt.cpan.org/Public/Bug/Display.html?id=71403
  - Thanks to Kevin.
  - Apply a pull request by ElDiablo with the implementation of
    lib/XML/LibXML/Devel.pm .
  - Adjust the Win32 Build Instructions in the README file.
  - Thanks to Christopher J. Madsen.
* Thu Sep 22 2011 vcizek@suse.com
- update to 1.88
  - Add libxml2 2.7.8 as tested and working fine for the Makefile.PL.
    (Thanks to H. Merijn Brand.).
  - Apply a patch to perl-libxml-sax.c to use xmlChar * instead of char *.
    (Thanks to H. Merijn Brand.).
  - Correct the README so it won't read XML-LibXML-Common.
  - see http://code.activestate.com/lists/perl-xml/8907/
  - Add a patch to implement the no_defdtd option in recent libxml2's:
  - https://rt.cpan.org/Ticket/Display.html?id=70878
  - Thanks to zzgrim@gmail.com .
  - Add scripts/bump-version-number.pl to modify the version number globally.
  - Currently the version numbers of the modules under lib/ where 1.73.
* Mon Aug 29 2011 vcizek@suse.com
- update to 1.87
  - Fix t/49callbacks_returning_undef.t to not read /etc/passed which may
    not be valid XML. Instead, we're reading a local file while using
    URI::file (assuming it exists - else - we skip_all.)
  1.86            Thu Aug 25 11:42:55 IDT 2011
  - Changed SvPVx_nolen() to SvPV_nolen() in LibXML.xs for better compatibility.
  - SvPVx_nolen() appears to be undocumented API.
  - Resolves https://rt.cpan.org/Public/Bug/Display.html?id=70476
  - Thanks to Paul for the report.
  1.85            Wed Aug 24 17:05:19 IDT 2011
  - Gracefully handle returned undef()s in the read callback under -w ($^W):
  - t/49callbacks_returning_undef.t
  - https://rt.cpan.org/Ticket/Display.html?id=70321
  - Add a patch from Mithaldu to get XML::LibXML to compile on Win32:
  - https://rt.cpan.org/Ticket/Display.html?id=70141
  - I'm applying it by faith, so if it breaks, blame him. (;-).
  - the patch adds -lllibgettextlib.dll to the Makefile.PL.
* Mon Jul 25 2011 vcizek@novell.com
- update to 1.84
  - fixes https://rt.cpan.org/Ticket/Display.html?id=69722 .
  - Fixed missing declarations after statements:
  - resolves https://rt.cpan.org/Ticket/Display.html?id=69622 again.
  - Fix docbook source validity
  - resolves https://rt.cpan.org/Ticket/Display.html?id=69702
  - Moved some if blocks after the dSP; (which contains declarations) to be
    compliant with C89/C90, which don't allow declarations in the middle of
    a C function.
  - resolves https://rt.cpan.org/Ticket/Display.html?id=69622
  - Fix https://rt.cpan.org/Ticket/Display.html?id=69553 :
  - "install_sax_driver doesn't like custom INSTALLARCHLIB"
  - Fix "IDs of elements is lost when importing nodes"
  - https://rt.cpan.org/Public/Bug/Display.html?id=69520
  - With t/48importing_nodes_IDs_rt_69520.t .
  - Convert all remaining Test.pm-based test scripts except t/14sax.t to
    Test::More .
  - Fix https://rt.cpan.org/Public/Bug/Display.html?id=69082 :
  - Compilation on strawberry perl.
  - The problem was that stderr required a dTHX; call previously.
  - DOM Normalisation patches and a fix for #69096
  - https://rt.cpan.org/Ticket/Display.html?id=69096
  - "findvalue from XML::LibXML 1.74 is very slow (regression)"
  - https://bitbucket.org/shlomif/perl-xml-libxml/pull-request/5/normalize-bug-fixes
  - Fix https://rt.cpan.org/Ticket/Display.html?id=69433 :
  - "t/19die_on_invalid_utf8_rt_58848.t assumes errors will be objects:"
  - Failed on older libxml2's.
  - Add a skip for t/60error_prev_chain.t in case $@ is true but not a ref.
  - https://rt.cpan.org/Ticket/Display.html?id=69435
  - http://www.cpantesters.org/cpan/report/4ac00aae-a73f-11e0-84bd-8881cd42d09c
* Mon Jul 11 2011 vcizek@novell.com
- update to 1.79
  - many rt bug fixes
  - most of the tests rewritten to use Test::More
  - dropped utf-16 patch (no longer needed)
* Thu Jun 16 2011 vcizek@novell.com
- update to 1.71
  - turn XML_LIBXML_PARSE_DEFAULTS constant to $XML::LibXML::XML_LIBXML_PARSE_DEFAULTS
  - Apply 0001-XML-LibXML-Error-no-need-to-AUTOLOAD-domain.patch from
    https://rt.cpan.org/Public/Bug/Display.html?id=68575 - no need to
    AUTOLOAD 'domain' because a method like that exists.
  - Apply 0002-XML-LibXML-Error-avoid-AUTOLOAD.patch from
    https://rt.cpan.org/Public/Bug/Display.html?id=68575 - get rid of
    AUTOLOAD completely.
  - Apply 0003-XML-LibXML-Error-make-domain-work-for-unknown-domain.patch
    from https://rt.cpan.org/Public/Bug/Display.html?id=68575 - handle
    unknown domains.
  - Apply 0004-XML-LibXML-Error-add-domains-from-newer-libxml2.patch
    from https://rt.cpan.org/Public/Bug/Display.html?id=68575 - add more
    errors.
  - Apply 0005-XML-LibXML-Error-avoid-malformed-UTF-8-warnings.patch
    from https://rt.cpan.org/Public/Bug/Display.html?id=68575
  - In replaceDataString - use
    http://perldoc.perl.org/functions/quotemeta.html instead of a long (and
    incomplete) list of characters to escape.
  - - With test.
  - - also fix deleteDataString by making it use replaceDataString
    for help.
  - - Fixing https://rt.cpan.org/Ticket/Display.html?id=68564
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Apr  2 2010 chris@computersalat.de
- fix build for suse_version 1110
- spec mods
  o sort TAGS
  o fix deps
  o update description, +Authors
  o macros
- added perl-macros
- rpmlint
  o fix self-obsoletion perl-XML-LibXML-Common
  - Provides = version
  - Obsoletes < version
* Thu Jan 14 2010 jfunk@funktronics.ca
- XML-LibXML-Common was merged into XML-LibXML 1.70. Removed
  Requires/BuildRequires and added Provides/Obsoletes
* Wed Jan 13 2010 anicka@suse.cz
- update to 1.70
  * various fixes and improvements in the documentation
  * added (convenient yet non-standard) methods nonBlankChildNodes,
    firstNonBlankChild, nextNonBlankSibling, prevNonBlankSibling
    that skip empty or whitespace-only Text and CDATA nodes
  * exposed and documented external entity handler
  * XPathContext can now be passed to toStringC14N and toStringEC14N
    (e.g. to provide NS mapping for the XPath expression)
  * avoid using libxml2's globals (Nick Wellnhofer)
  * added interface to libxml2's regexp implementation: XML::LibXML::RegExp
  * added XML::LibXML->load_xml and XML::LibXML->load_html with
    uniform and cleaner API than the old parse_* family
  * cleanup code dealing with parsing flags
  * fix bogus validation results if revalidating a modified document
  * added 'eq' and 'cmp' overloading on XML::LibXML::Error and set fallback to 1
  * lots of bugs fixed
  * provide context and more accurate column number in
    structured errors
  * clarify license and copyright
  * support for Win32+mingw+ActiveState
  * merge with XML::LibXML::Common
  * fix compilation on Windows with mingw or msvc
  * fix a bug in structured errors preventing the previous errors from being reported
  * fix compilation bugs
  * fix encoding problem in reader
  * added getAttributeHash to the reader interface
  * fix segfaults: reconcileNs in domReplaceChild, findnodes with a doc fragment
* Thu Jan 22 2009 anicka@suse.cz
- update to 1.69
  * fix incorrect output of getAttributeNS and possibly other
  methods on UTF-8
  * added $node_or_xpc->exists($xpath) method
  * remove accidental debug output from XML::LibXML::SAX::Builder
  * compilation problem fixes
  * many bugfixes (rt.cpan.org)
  * added XML::LibXML::Pattern module and extended pattern
  support in Reader
  * added XML::LibXML::XPathExpression module that can pre-compile
  an XPath expression
  * reimplementation of the thread support
  * structured errors XML::LibXML::Error
  * memory leak fixes
  * documentation fixes
  * README - notes for building on Win32
- temporarily disabled two utf16 tests that fail due to our
  old libxml
* Tue Feb  5 2008 anicka@suse.cz
- update to 1.66
  * Perl-thread support
  * make Reader interface require Perl 5.8
  * strip-off UTF8 flag with $node->toString($format,1) for
    consistent behavior independent on the actual document
    encoding
  * skip tests that require Encode module if not available
  * finally removed the iterator() method deprecated since 1.54
  * set_document_locator support in XML::LibXML::SAX::Parser
  * XML::LibXML::Namespace API fixed in order to achieve
    an agreement between the docs and the implementation
  * added support for exclusive canonicalization
    (http://www.w3.org/TR/xml*exc-c14n/)
  * bugfixes, test fixes, documentation fixes
- enable tests in %%check section
* Fri Jun  1 2007 coolo@suse.de
- remove libxml2-test from buildrequires
* Wed Dec 13 2006 anicka@suse.cz
- update to 1.62001
  * interface to libxml2's pull-parser XML::LibXML::Reader
  * make error messages intended to the user report the line of the
    application call rather than that of the internal XS call
  * XML::LibXML::Attr->serializeContent added
  * fix getAttributeNode etc. w.r.t.
  * warn if runtime libxml2 is older than the one used at the
    compile time
  * if compiled against libxml2 >= 2.6.27, new parse_html_*
    implementation is used allowing encoding and other options
    to be passed to the parser
  * DOM-compliant nodeNames: #comment, #text, #cdata, #document,
    [#]document-fragment
  * toString on empty text node returns empty string, not undef
  * cloneNode copies attributes on an element as required
    by the DOM spec
* Mon Sep 25 2006 anicka@suse.cz
- update to 1.61
  * get{Elements,Children}By{TagName,TagNameNS,LocalName} now
    obey wildcards '*', getChildrenByLocalName was added.
  * XML::LibXML::XPathContext merged in
  * many new tests added
  * the module should now be fully compatibile with
    libxml2 >= 2.6.16
  * threads test skipped by default
  * documentation updates
  * added setNamespaceDecl{URI,Prefix}
  * get/setAttribute(NS)? implementation made xmlns aware
  * all sub-modules have the same version as XML::LibXML
* Thu Sep 14 2006 anicka@suse.cz
- update to 1.60
  * remove the SGML parser code no longer supported by libxml
  * documentation and regression fixes and enhancements
  * added publicId and systemId methods to XML::LibXML::Dtd
  * new XML::LibXML::InputCallback class
  * new parser and callback code
  * bugfixes
* Wed Mar 15 2006 anicka@suse.cz
- require perl-XML-LibXML-Common and  perl-XML-SAX (#158024)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug 19 2004 mjancar@suse.cz
- update to 1.58
* Wed Mar  3 2004 mjancar@suse.cz
- initial version 1.57
